@@ -95,7 +95,7 @@ test_that("basic examples work", {
 	wfs_data <- item_get_wfs("58c988bce4b0849ce97b4845"),
 	"item_get_wfs is going to be removed in a future version of sbtools")
 	
-	expect_equal(as.character(class(wfs_data)), "SpatialPointsDataFrame")
+	wexpect_equal(as.character(class(wfs_data)), "SpatialPointsDataFrame")
 	
 	suppressWarnings(wfs_data <- item_get_wfs("58c988bce4b0849ce97b4845", as_sf = TRUE))
 	
